/*
 * @(#)SoftReferenceCharset.java        0.0        09/07/29
 *
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 * SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 * Contributors: Ulf Zibis, Germany, Ulf.Zibis @ CoSoCo.de
 */

package sun.nio.cs;

import java.lang.ref.SoftReference;

/**
 * Class for charsets with huge mapping footprint; caches coders as SoftReference.
 *
 * @author Ulf Zibis, Cologne <Ulf.Zibis @ CoSoCo.de>
 */
public class SoftReferenceCharset extends FastCharset {

    private transient SoftReference<Decoder> decoderRef;
    private transient SoftReference<Encoder> encoderRef;

    protected SoftReferenceCharset(String packageName, String className, String canonicalName, String[] aliases) {
        super(packageName, className, canonicalName, aliases);
    }

    Decoder decoder() {
        Decoder decoder;
        if (decoderRef == null || (decoder = decoderRef.get()) == null)
            decoderRef = new SoftReference(decoder = mapping().newDecoder(this));
        return decoder;
    }

    Encoder encoder() {
        Encoder encoder;
        if (encoderRef == null || (encoder = encoderRef.get()) == null)
            encoderRef = new SoftReference(encoder = decoder().mapping.newEncoder(this));
        return encoder;
    }
}
